==> typestyle-0.19.2.tgz: package/lib.es2015/index.js <==
import { ensureString, ensureStringObj } from './internal/formatting';
/**
 * All the CSS types in the 'types' namespace
 */
import * as types from './types';
export { types };
/**
 * @module Maintains a single stylesheet and keeps it in sync with requested styles
 */
import * as FreeStyle from "free-style";
/** Raf for node + browser */
var raf = typeof requestAnimationFrame === 'undefined' ? setTimeout : requestAnimationFrame;
/**
 * Only calls cb all sync operations settle
 */
var afterAllSync = (new (function () {
    function class_1() {
        var _this = this;
        this.pending = 0;
        this.afterAllSync = function (cb) {
            _this.pending++;
            var pending = _this.pending;
            raf(function () {
                if (pending !== _this.pending)
                    return;
                cb();
            });
        };
    }
    return class_1;
}())).afterAllSync;
/**
 * We have a single stylesheet that we update as components register themselves
 */
var freeStyle = FreeStyle.create();
var lastFreeStyleChangeId = freeStyle.changeId;
/**
 * We create a tag on first request or return the one that was hydrated
 */
var _a = new (function () {
    function class_2() {
        var _this = this;
        this.singletonTag = undefined;
        this.getTag = function () {
            if (!_this.singletonTag) {
                _this.singletonTag = typeof window === 'undefined' ? { textContent: '' } : document.createElement('style');
                if (typeof document !== 'undefined')
                    document.head.appendChild(_this.singletonTag);
            }
            return _this.singletonTag;
        };
        this.setTag = function (tag) {
            /** Clear any data in any previous tag */
            if (_this.singletonTag) {
                _this.singletonTag.textContent = '';
            }
            _this.singletonTag = tag;
            /** This special time buffer immediately */
            forceRenderStyles();
        };
    }
    return class_2;
}()), setTag = _a.setTag, getTag = _a.getTag;
/** Sets the target tag where we write the css on style updates */
export var setStylesTarget = setTag;
/** Checks if the style tag needs updating and if so queues up the change */
var styleUpdated = function () {
    if (freeStyle.changeId === lastFreeStyleChangeId
        && !pendingRawChange)
        return;
    lastFreeStyleChangeId = freeStyle.changeId;
    pendingRawChange = false;
    afterAllSync(forceRenderStyles);
};
var pendingRawChange = false;
var raw = '';
/**
 * Insert `raw` CSS as a string. This is useful for e.g.
 * - third party CSS that you are customizing with template strings
 * - generating raw CSS in JavaScript
 * - reset libraries like normalize.css that you can use without loaders
 */
export function cssRaw(mustBeValidCSS) {
    if (!mustBeValidCSS)
        return;
    raw = raw + mustBeValidCSS;
    pendingRawChange = true;
    styleUpdated();
}
/**
 * Renders styles to the singleton tag imediately
 * NOTE: You should only call it on initial render to prevent any non CSS flash.
 * After that it is kept sync using `requestAnimationFrame` and we haven't noticed any bad flashes.
 **/
export function forceRenderStyles() {
    getTag().textContent = getStyles();
}
/**
 * Helps with testing. Reinitializes FreeStyle + raw
 */
export function reinit() {
    /** reinit freestyle */
    freeStyle = FreeStyle.create();
    lastFreeStyleChangeId = freeStyle.changeId;
    /** reinit raw */
    raw = '';
    pendingRawChange = false;
    /** Clear any styles that were flushed */
    getTag().textContent = '';
}
/**
 * Allows use to use the stylesheet in a node.js environment
 */
export var getStyles = function () { return raw ? raw + freeStyle.getStyles() : freeStyle.getStyles(); };
/**
 * Takes CSSProperties and return a generated className you can use on your component
 */
export function style() {
    var objects = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        objects[_i] = arguments[_i];
    }
    var _a = ensureStringObj(extend.apply(void 0, objects)), result = _a.result, debugName = _a.debugName;
    var className = debugName ? freeStyle.registerStyle(result, debugName) : freeStyle.registerStyle(result);
    styleUpdated();
    return className;
}
export function fontFace() {
    var fontFace = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        fontFace[_i] = arguments[_i];
    }
    for (var _a = 0, fontFace_1 = fontFace; _a < fontFace_1.length; _a++) {
        var face = fontFace_1[_a];
        freeStyle.registerRule('@font-face', face);
    }
    styleUpdated();
    return;
}
/**
 * Takes CSSProperties and registers it to a global selector (body, html, etc.)
 */
export function cssRule(selector) {
    var objects = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        objects[_i - 1] = arguments[_i];
    }
    var object = ensureStringObj(extend.apply(void 0, objects)).result;
    freeStyle.registerRule(selector, object);
    styleUpdated();
    return;
}
/**
 * Takes Keyframes and returns a generated animation name
 */
export function keyframes(frames) {
    // resolve keyframe css property helpers
    for (var key in frames) {
        var frame = frames[key];
        for (var prop in frame) {
            frame[prop] = ensureString(frame[prop]);
        }
    }
    var animationName = freeStyle.registerKeyframes(frames);
    styleUpdated();
    return animationName;
}
/**
 * Helper for you to create a CSSFunction
 * Assumption is that most css function fall into this pattern:
 * `function-name(param [, param])`
 */
export function cssFunction(functionName) {
    var params = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        params[_i - 1] = arguments[_i];
    }
    var parts = params.map(ensureString).join(',');
    return functionName + "(" + parts + ")";
}
/**
 * Merges various styles into a single style object.
 * Note: if two objects have the same property the last one wins
 */
export function extend() {
    var objects = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        objects[_i] = arguments[_i];
    }
    /** The final result we will return */
    var result = {};
    for (var _a = 0, objects_1 = objects; _a < objects_1.length; _a++) {
        var object = objects_1[_a];
        for (var key in object) {
            /** Falsy values except a explicit 0 is ignored */
            var val = object[key];
            if (!val && val !== 0) {
                continue;
            }
            /** if nested media or pseudo selector */
            if (key === '$nest' && val) {
                result[key] = result['$nest'] ? extend(result['$nest'], val) : val;
            }
            else if ((key.indexOf('&') !== -1 || key.indexOf('@media') === 0)) {
                result[key] = result[key] ? extend(result[key], val) : val;
            }
            else {
                result[key] = val;
            }
        }
    }
    return result;
}
/**
 * Utility to join classes conditionally
 */
export function classes() {
    var classes = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        classes[_i] = arguments[_i];
    }
    return classes.filter(function (c) { return !!c; }).join(' ');
}
/**
 * Helps customize styles with media queries
 */
export var media = function (mediaQuery) {
    var objects = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        objects[_i - 1] = arguments[_i];
    }
    var mediaQuerySections = [];
    if (mediaQuery.type)
        mediaQuerySections.push(mediaQuery.type);
    if (mediaQuery.orientation)
        mediaQuerySections.push(mediaQuery.orientation);
    if (mediaQuery.minWidth)
        mediaQuerySections.push("(min-width: " + mediaQuery.minWidth + "px)");
    if (mediaQuery.maxWidth)
        mediaQuerySections.push("(max-width: " + mediaQuery.maxWidth + "px)");
    var stringMediaQuery = "@media " + mediaQuerySections.join(' and ');
    var object = {
        $nest: (_a = {},
            _a[stringMediaQuery] = extend.apply(void 0, objects),
            _a)
    };
    return object;
    var _a;
};

==> typestyle-0.20.0.tgz: package/lib.es2015/index.js <==
import { ensureStringObj } from './internal/formatting';
/**
 * All the CSS types in the 'types' namespace
 */
import * as types from './types';
export { types };
/**
 * @module Maintains a single stylesheet and keeps it in sync with requested styles
 */
import * as FreeStyle from "free-style";
/** Raf for node + browser */
var raf = typeof requestAnimationFrame === 'undefined' ? setTimeout : requestAnimationFrame;
/**
 * Only calls cb all sync operations settle
 */
var afterAllSync = (new (function () {
    function class_1() {
        var _this = this;
        this.pending = 0;
        this.afterAllSync = function (cb) {
            _this.pending++;
            var pending = _this.pending;
            raf(function () {
                if (pending !== _this.pending)
                    return;
                cb();
            });
        };
    }
    return class_1;
}())).afterAllSync;
/**
 * We have a single stylesheet that we update as components register themselves
 */
var freeStyle = FreeStyle.create();
var lastFreeStyleChangeId = freeStyle.changeId;
/**
 * We create a tag on first request or return the one that was hydrated
 */
var _a = new (function () {
    function class_2() {
        var _this = this;
        this.singletonTag = undefined;
        this.getTag = function () {
            if (!_this.singletonTag) {
                _this.singletonTag = typeof window === 'undefined' ? { textContent: '' } : document.createElement('style');
                if (typeof document !== 'undefined')
                    document.head.appendChild(_this.singletonTag);
            }
            return _this.singletonTag;
        };
        this.setTag = function (tag) {
            /** Clear any data in any previous tag */
            if (_this.singletonTag) {
                _this.singletonTag.textContent = '';
            }
            _this.singletonTag = tag;
            /** This special time buffer immediately */
            forceRenderStyles();
        };
    }
    return class_2;
}()), setTag = _a.setTag, getTag = _a.getTag;
/** Sets the target tag where we write the css on style updates */
export var setStylesTarget = setTag;
/** Checks if the style tag needs updating and if so queues up the change */
var styleUpdated = function () {
    if (freeStyle.changeId === lastFreeStyleChangeId
        && !pendingRawChange)
        return;
    lastFreeStyleChangeId = freeStyle.changeId;
    pendingRawChange = false;
    afterAllSync(forceRenderStyles);
};
var pendingRawChange = false;
var raw = '';
/**
 * Insert `raw` CSS as a string. This is useful for e.g.
 * - third party CSS that you are customizing with template strings
 * - generating raw CSS in JavaScript
 * - reset libraries like normalize.css that you can use without loaders
 */
export function cssRaw(mustBeValidCSS) {
    if (!mustBeValidCSS)
        return;
    raw = raw + mustBeValidCSS;
    pendingRawChange = true;
    styleUpdated();
}
/**
 * Renders styles to the singleton tag imediately
 * NOTE: You should only call it on initial render to prevent any non CSS flash.
 * After that it is kept sync using `requestAnimationFrame` and we haven't noticed any bad flashes.
 **/
export function forceRenderStyles() {
    getTag().textContent = getStyles();
}
/**
 * Helps with testing. Reinitializes FreeStyle + raw
 */
export function reinit() {
    /** reinit freestyle */
    freeStyle = FreeStyle.create();
    lastFreeStyleChangeId = freeStyle.changeId;
    /** reinit raw */
    raw = '';
    pendingRawChange = false;
    /** Clear any styles that were flushed */
    getTag().textContent = '';
}
/**
 * Allows use to use the stylesheet in a node.js environment
 */
export var getStyles = function () { return raw ? raw + freeStyle.getStyles() : freeStyle.getStyles(); };
/**
 * Takes CSSProperties and return a generated className you can use on your component
 */
export function style() {
    var objects = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        objects[_i] = arguments[_i];
    }
    var _a = ensureStringObj(extend.apply(void 0, objects)), result = _a.result, debugName = _a.debugName;
    var className = debugName ? freeStyle.registerStyle(result, debugName) : freeStyle.registerStyle(result);
    styleUpdated();
    return className;
}
export function fontFace() {
    var fontFace = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        fontFace[_i] = arguments[_i];
    }
    for (var _a = 0, fontFace_1 = fontFace; _a < fontFace_1.length; _a++) {
        var face = fontFace_1[_a];
        freeStyle.registerRule('@font-face', face);
    }
    styleUpdated();
    return;
}
/**
 * Takes CSSProperties and registers it to a global selector (body, html, etc.)
 */
export function cssRule(selector) {
    var objects = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        objects[_i - 1] = arguments[_i];
    }
    var object = ensureStringObj(extend.apply(void 0, objects)).result;
    freeStyle.registerRule(selector, object);
    styleUpdated();
    return;
}
/**
 * Takes Keyframes and returns a generated animation name
 */
export function keyframes(frames) {
    // resolve keyframe css property helpers
    for (var key in frames) {
        var frame = frames[key];
        for (var prop in frame) {
            frame[prop] = frame[prop].toString();
        }
    }
    var animationName = freeStyle.registerKeyframes(frames);
    styleUpdated();
    return animationName;
}
/**
 * Helper for you to create a CSSFunction
 * Assumption is that most css function fall into this pattern:
 * `function-name(param [, param])`
 */
export function cssFunction(functionName) {
    var params = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        params[_i - 1] = arguments[_i];
    }
    var parts = params.map(function (s) { return s.toString(); }).join(',');
    return functionName + "(" + parts + ")";
}
/**
 * Merges various styles into a single style object.
 * Note: if two objects have the same property the last one wins
 */
export function extend() {
    var objects = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        objects[_i] = arguments[_i];
    }
    /** The final result we will return */
    var result = {};
    for (var _a = 0, objects_1 = objects; _a < objects_1.length; _a++) {
        var object = objects_1[_a];
        for (var key in object) {
            /** Falsy values except a explicit 0 is ignored */
            var val = object[key];
            if (!val && val !== 0) {
                continue;
            }
            /** if nested media or pseudo selector */
            if (key === '$nest' && val) {
                result[key] = result['$nest'] ? extend(result['$nest'], val) : val;
            }
            else if ((key.indexOf('&') !== -1 || key.indexOf('@media') === 0)) {
                result[key] = result[key] ? extend(result[key], val) : val;
            }
            else {
                result[key] = val;
            }
        }
    }
    return result;
}
/**
 * Utility to join classes conditionally
 */
export function classes() {
    var classes = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        classes[_i] = arguments[_i];
    }
    return classes.filter(function (c) { return !!c; }).join(' ');
}
/**
 * Helps customize styles with media queries
 */
export var media = function (mediaQuery) {
    var objects = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        objects[_i - 1] = arguments[_i];
    }
    var mediaQuerySections = [];
    if (mediaQuery.type)
        mediaQuerySections.push(mediaQuery.type);
    if (mediaQuery.orientation)
        mediaQuerySections.push(mediaQuery.orientation);
    if (mediaQuery.minWidth)
        mediaQuerySections.push("(min-width: " + mediaQuery.minWidth + "px)");
    if (mediaQuery.maxWidth)
        mediaQuerySections.push("(max-width: " + mediaQuery.maxWidth + "px)");
    var stringMediaQuery = "@media " + mediaQuerySections.join(' and ');
    var object = {
        $nest: (_a = {},
            _a[stringMediaQuery] = extend.apply(void 0, objects),
            _a)
    };
    return object;
    var _a;
};
